@@ -1,7 +1,7 @@
-from . import type
+from . import _type
 from . import _pyctyerror
 
-class array(type.CType):
+class array(_type.CType):
     def __init__(self,value : int):
         self.value = value
     def __str__(self):
