@@ -1,7 +1,7 @@
-from . import type
+from . import _type
 from . import _pyctyerror
 
-class array(type.CType):
+class array(_type.CType):
     def __init__(self,value : str):
         if len(value) != 1:
             raise _pyctyerror.PyCTYError("char must be one letter")
